Teruskan tunnel SSH

Di Datastream, tunnel SSH penerusan memungkinkan Anda membuat koneksi terenkripsi ke database sumber melalui jaringan publik. Untuk menyiapkan metode konektivitas ini, Anda memilih host penghentian, mengizinkan traffic dari alamat IP Datastream, dan mengonfigurasi tunnel di profil koneksi.

Langkah 1: Pilih host untuk menghentikan tunnel

Langkah pertama dalam menyiapkan akses tunnel SSH untuk database Anda adalah memilih host yang akan digunakan untuk menghentikan tunnel. Tunnel dapat dihentikan di host database itu sendiri, atau di host terpisah (server tunnel).

Menggunakan server database

Menghentikan tunnel di database memiliki keunggulan dalam hal kemudahan. Jumlah host yang terlibat berkurang satu, sehingga tidak ada mesin tambahan dan biaya terkaitnya. Kelemahannya adalah server database Anda mungkin berada di jaringan yang dilindungi dan tidak memiliki akses langsung dari internet.

Menggunakan server tunnel

Menghentikan tunnel di server terpisah memiliki keuntungan, yaitu menjaga server database Anda agar tidak dapat diakses dari internet. Jika server tunnel disusupi, server tersebut akan berada satu langkah lebih dekat ke server database. Sebaiknya hapus semua software dan pengguna yang tidak penting dari server tunnel dan pantau dengan cermat menggunakan alat, seperti sistem deteksi penyusupan (IDS).

Server tunnel dapat berupa host Unix atau Linux apa pun yang:

  1. Dapat diakses dari internet menggunakan SSH.
  2. Dapat mengakses database.

Langkah 2: Buat daftar IP yang diizinkan

Langkah kedua untuk menyiapkan akses tunnel SSH untuk database Anda adalah mengizinkan traffic jaringan menjangkau server tunnel atau host database menggunakan SSH, yang umumnya berada di port TCP 22.

Izinkan traffic jaringan dari setiap alamat IP untuk region tempat resource Datastream dibuat.

Langkah 3: Menggunakan tunnel SSH

Berikan detail tunnel dalam konfigurasi profil koneksi. Untuk mengetahui informasi selengkapnya, lihat Membuat profil koneksi.

Untuk mengautentikasi sesi tunnel SSH, Datastream memerlukan sandi untuk akun tunnel, atau kunci pribadi yang unik. Untuk menggunakan kunci pribadi yang unik, Anda dapat menggunakan alat command line OpenSSH atau OpenSSL untuk membuat kunci.

Datastream menyimpan kunci pribadi dengan aman sebagai bagian dari konfigurasi profil koneksi Datastream. Anda harus menambahkan kunci publik secara manual ke file ~/.ssh/authorized_keys bastion host.

Membuat kunci pribadi dan publik

Anda dapat membuat kunci SSH menggunakan metode berikut:

  • ssh-keygen: Alat command line OpenSSH untuk membuat pasangan kunci SSH.

    Flag yang berguna:

    • -t: Menentukan jenis kunci yang akan dibuat, misalnya:

      ssh-keygen -t rsa

      ssh-keygen -t ed25519

    • -b: Menentukan panjang kunci dalam kunci yang akan dibuat, misalnya:

      ssh-keygen -t rsa -b 2048

    • -y: Membaca file format OpenSSH pribadi dan mencetak kunci publik OpenSSH ke output standar.

    • -f: Menentukan nama file kunci, misalnya:

      ssh-keygen -y [-f KEY_FILENAME]

    Untuk mengetahui informasi selengkapnya tentang flag yang didukung, lihat dokumentasi OpenBSD.

Anda dapat membuat kunci PEM pribadi menggunakan metode berikut:

  • openssl genpkey: Alat command line OpenSSL untuk membuat kunci pribadi PEM.

    Flag yang berguna:

    • algorithm: Menentukan algoritma kunci publik yang akan digunakan, misalnya:

      openssl genpkey -algorithm RSA

    • -out: Menentukan nama file untuk menghasilkan kunci, misalnya:

      openssl genpkey -algorithm RSA -out PRIVATE_KEY_FILENAME.pem

    Untuk mengetahui informasi selengkapnya tentang flag yang didukung, lihat dokumentasi OpenSSL.

Langkah berikutnya